@@ -6,20 +6,20 @@ package File::Flat;
 # This should work on non-Unix platforms, but there may be some
 # minor remaining bugs.
 
+use 5.005;
 use strict;
-use UNIVERSAL 'isa';
-use Cwd         ();
-use File::Spec  ();
-use IO::File    ();
-use prefork 'File::Slurp';
-use prefork 'File::Temp';
-use prefork 'File::Copy';
-use prefork 'File::NCopy';
-use prefork 'File::Remove';
+use Cwd        ();
+use File::Spec ();
+use IO::File   ();
+use prefork    'File::Slurp';
+use prefork    'File::Temp';
+use prefork    'File::Copy';
+use prefork    'File::Copy::Recursive';
+use prefork    'File::Remove';
 
 use vars qw{$VERSION $errstr %modes $AUTO_PRUNE};
 BEGIN {
-	$VERSION = '0.95';
+	$VERSION = '1.00';
 
 	# The main error string
 	$errstr  = '';
@@ -221,7 +221,7 @@ sub write {
 	# This also makes sure the stuff we are going to write is ok.
 	my $contents;
 	if ( ref $_[0] ) {
-		unless ( isa( $_[0], 'SCALAR' ) or isa( $_[0], 'ARRAY' ) ) {
+		unless ( UNIVERSAL::isa($_[0], 'SCALAR') or UNIVERSAL::isa($_[0], 'ARRAY') ) {
 			return $class->_error( "Unknown or invalid argument to ->write" );
 		}
 
@@ -244,7 +244,7 @@ sub write {
 	}
 
 	# Write the contents to the handle
-	if ( isa( $contents, 'SCALAR' ) ) {
+	if ( UNIVERSAL::isa($contents, 'SCALAR') ) {
 		$file->print( $$contents ) or return undef;
 	} else {
 		foreach ( @$contents ) {
@@ -367,9 +367,9 @@ sub copy {
 			"Failed to create directory '$target'" );
 	}
 
-	# Hand off to File::NCopy
-	require File::NCopy;
-	my $rv = File::NCopy::copy( \1, $tocopy, $target );
+	# Hand off to File::Copy::Recursive
+	require File::Copy::Recursive;
+	my $rv = File::Copy::Recursive::dircopy( $tocopy, $target );
 	defined $rv ? $rv : $class->_andRemove( $remove_on_fail );
 }
 
@@ -512,7 +512,6 @@ package File::Flat::Object;
 # The methods are the same as for File::Flat, where applicable.
 
 use strict;
-use UNIVERSAL 'isa';
 use File::Spec ();
 
 sub new {
@@ -706,13 +705,14 @@ sub prune {
 		# Does it contain anything, other that (possibly) curdir and updir entries
 		opendir( PRUNEDIR, $dir )
 			or return $self->_error("opendir failed while pruning: $!");
-		foreach ( readdir PRUNEDIR ) {
+		my @files = readdir PRUNEDIR;
+		closedir PRUNEDIR;
+		foreach ( @files ) {
 			next if $_ eq File::Spec->curdir;
 			next if $_ eq File::Spec->updir;
 
 			# Found something, we don't need to prune this,
 			# or anything else for that matter.
-			closedir PRUNEDIR;
 			return 1;
 		}
 
@@ -849,8 +849,8 @@ All methods are statically called, for example, to write some stuff to a file.
 =head2 Use of other modules
 
 File::Flat tries to use more task orientated modules wherever possible. This
-includes the use of File::Copy, File::NCopy, File::Remove and others. These
-are mostly loaded on-demand.
+includes the use of L<File::Copy>, L<File::Copy::Recursive>, L<File::Remove>
+and others. These are mostly loaded on-demand.
 
 =head2 Pruning and $AUTO_PRUNE
 
@@ -885,13 +885,8 @@ this locally, such as in the following example.
 
 =head2 Non-Unix platforms
 
-File::Flat itself should be completely capable of handling any platform
-through its exclusive use of File::Spec.
-
-However, some of the modules it relies upon, particularly File::Remove, and
-possible File::NCopy are not File::Spec happy yet. Results may wary on non
-Unix platforms. Users of non-Unix platforms are invited to patch
-File::Remove ( and possibly File::NCopy ) and File::Flat should work.
+As of version 0.97 File::Flat should work correctly on Win32. Other
+platforms (such as VMS) are believed to work, but require confirmation.
 
 =head1 METHODS
 
@@ -1109,8 +1104,7 @@ Returns true on success, returns undef on error.
 =head1 TO DO
 
 Function interface to be written, like
-L<File::Spec::Functions|File::Spec::Functions>, to provide importable
-functions.
+L<File::Spec::Functions>, to provide importable functions.
 
 There's something bigger here too, I'm not exactly sure what it is,
 but I think there might be the beginings of a unified filesystem
@@ -1120,21 +1114,21 @@ interface here... FSI.pm
 
 Bugs should be filed at via the CPAN bug tracker at:
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File%3A%3AFlat>
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Flat>
 
 For other issues or comments, contact the author
 
 =head1 AUTHORS
 
-Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<File::Spec|File::Spec>
+L<File::Spec>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002 - 2004 Adam Kennedy. All rights reserved.
+Copyright (c) 2002 - 2006 Adam Kennedy. All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
